summaryrefslogtreecommitdiffstats
path: root/kmail/kmedit.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/kmedit.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmedit.cpp')
-rw-r--r--kmail/kmedit.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kmail/kmedit.cpp b/kmail/kmedit.cpp
index 46fd2a83..5442bef4 100644
--- a/kmail/kmedit.cpp
+++ b/kmail/kmedit.cpp
@@ -82,7 +82,7 @@ void KMEdit::keyPressEvent( TQKeyEvent* e )
int line, col;
getCursorPosition( &line, &col );
TQString lineText = text( line );
// returns line with additional trailing space (bug in Qt?), cut it off
lineText.truncate( lineText.length() - 1 );
// special treatment of quoted lines only if the cursor is neither at
// the begin nor at the end of the line
@@ -112,7 +112,7 @@ void KMEdit::keyPressEvent( TQKeyEvent* e )
&& ( col >= int( bot ) ) ) {
// The cursor position might have changed unpredictably if there was selected
- // text which got tqreplaced by a new line, so we query it again:
+ // text which got replaced by a new line, so we query it again:
getCursorPosition( &line, &col );
TQString newLine = text( line );
// remove leading white space from the new line and instead
@@ -209,10 +209,10 @@ void KMEdit::contentsDropEvent(TQDropEvent *e)
}
}
-KMEdit::KMEdit(TQWidget *parent, KMComposeWin* composer,
+KMEdit::KMEdit(TQWidget *tqparent, KMComposeWin* composer,
KSpellConfig* autoSpellConfig,
const char *name)
- : KEdit( parent, name ),
+ : KEdit( tqparent, name ),
mComposer( composer ),
mKSpellForDialog( 0 ),
mSpeller( 0 ),
@@ -225,7 +225,7 @@ KMEdit::KMEdit(TQWidget *parent, KMComposeWin* composer,
mWasModifiedBeforeSpellCheck( false ),
mHighlighter( 0 ),
mSpellLineEdit( false ),
- mPasteMode( QClipboard::Clipboard )
+ mPasteMode( TQClipboard::Clipboard )
{
connect( this, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotSelectionChanged()) );
installEventFilter(this);
@@ -253,7 +253,7 @@ void KMEdit::initializeAutoSpellChecking()
TQColor defaultColor3( 0x00, 0x60, 0x00 );
TQColor defaultForeground( kapp->palette().active().text() );
- TQColor c = Qt::red;
+ TQColor c = TQt::red;
KConfigGroup readerConfig( KMKernel::config(), "Reader" );
TQColor col1;
if ( !readerConfig.readBoolEntry( "defaultColors", true ) )
@@ -356,7 +356,7 @@ unsigned int KMEdit::lineBreakColumn() const
unsigned int lineBreakColumn = 0;
unsigned int numlines = numLines();
while ( numlines-- ) {
- lineBreakColumn = QMAX( lineBreakColumn, textLine( numlines ).length() );
+ lineBreakColumn = TQMAX( lineBreakColumn, textLine( numlines ).length() );
}
return lineBreakColumn;
}
@@ -447,8 +447,8 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
sysLine += " ";
while (!sysLine.isEmpty())
{
- *mExtEditorProcess << sysLine.left(sysLine.find(" ")).local8Bit();
- sysLine.remove(0, sysLine.find(" ") + 1);
+ *mExtEditorProcess << sysLine.left(sysLine.tqfind(" ")).local8Bit();
+ sysLine.remove(0, sysLine.tqfind(" ") + 1);
}
connect(mExtEditorProcess, TQT_SIGNAL(processExited(KProcess*)),
TQT_SLOT(slotExternalEditorDone(KProcess*)));
@@ -498,7 +498,7 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
//Get word right clicked on
const TQRegExp wordBoundary( "[\\s\\W]" );
firstSpace = paraText.findRev( wordBoundary, charPos ) + 1;
- lastSpace = paraText.find( wordBoundary, charPos );
+ lastSpace = paraText.tqfind( wordBoundary, charPos );
if( lastSpace == -1 )
lastSpace = paraText.length();
TQString word = paraText.mid( firstSpace, lastSpace - firstSpace );
@@ -581,7 +581,7 @@ bool KMEdit::eventFilter(TQObject*o, TQEvent* e)
int KMEdit::autoSpellChecking( bool on )
{
- if ( textFormat() == Qt::RichText ) {
+ if ( textFormat() == TQt::RichText ) {
// syntax highlighter doesn't support extended text properties
if ( on )
KMessageBox::sorry(this, i18n("Automatic spellchecking is not possible on text with markup."));
@@ -649,7 +649,7 @@ void KMEdit::spellcheck()
mWasModifiedBeforeSpellCheck = isModified();
mSpellLineEdit = !mSpellLineEdit;
// maybe for later, for now plaintext is given to KSpell
-// if (textFormat() == Qt::RichText ) {
+// if (textFormat() == TQt::RichText ) {
// kdDebug(5006) << "KMEdit::spellcheck, spellchecking for RichText" << endl;
// mKSpellForDialog = new KSpell(this, i18n("Spellcheck - KMail"), this,
// TQT_SLOT(slotSpellcheck2(KSpell*)),0,true,false,KSpell::HTML);
@@ -679,21 +679,21 @@ void KMEdit::spellcheck()
void KMEdit::cut()
{
KEdit::cut();
- if ( textFormat() != Qt::RichText && mHighlighter )
+ if ( textFormat() != TQt::RichText && mHighlighter )
mHighlighter->restartBackgroundSpellCheck();
}
void KMEdit::clear()
{
KEdit::clear();
- if ( textFormat() != Qt::RichText && mHighlighter )
+ if ( textFormat() != TQt::RichText && mHighlighter )
mHighlighter->restartBackgroundSpellCheck();
}
void KMEdit::del()
{
KEdit::del();
- if ( textFormat() != Qt::RichText && mHighlighter )
+ if ( textFormat() != TQt::RichText && mHighlighter )
mHighlighter->restartBackgroundSpellCheck();
}
@@ -709,11 +709,11 @@ void KMEdit::paste()
// Roll our own internal flag.
void KMEdit::contentsMouseReleaseEvent( TQMouseEvent * e )
{
- if( e->button() != Qt::MidButton )
+ if( e->button() != TQt::MidButton )
return KEdit::contentsMouseReleaseEvent( e );
- mPasteMode = QClipboard::Selection;
+ mPasteMode = TQClipboard::Selection;
KEdit::contentsMouseReleaseEvent( e );
- mPasteMode = QClipboard::Clipboard;
+ mPasteMode = TQClipboard::Clipboard;
}
void KMEdit::contentsMouseDoubleClickEvent( TQMouseEvent *e )
@@ -828,7 +828,7 @@ void KMEdit::slotSpellcheck2(KSpell*)
kdDebug(5006) << "spelling: new SpellingFilter with prefix=\"" << quotePrefix << "\"" << endl;
TQTextEdit plaintext;
plaintext.setText(text());
- plaintext.setTextFormat(Qt::PlainText);
+ plaintext.setTextFormat(TQt::PlainText);
mSpellingFilter = new SpellingFilter(plaintext.text(), quotePrefix, SpellingFilter::FilterUrls,
SpellingFilter::FilterEmailAddresses);
@@ -82,7 +82,7 @@ void KMEdit::keyPressEvent( TQKeyEvent* e )
getCursorPosition( &line, &col );
TQString lineText = text( line );
- // returns line with additional trailing space (bug in Qt?), cut it off
+ // returns line with additional trailing space (bug in TQt?), cut it off
lineText.truncate( lineText.length() - 1 );
// special treatment of quoted lines only if the cursor is neither at